<?php

namespace App\Http\Middleware;

use Closure;
use Illuminate\Http\Request;
use Illuminate\Support\Facades\DB;
use Illuminate\Support\Facades\Config;
use Artisan;
use Session;

class SetBd
{
  /**
   * Handle an incoming request.
   *
   * @param  \Illuminate\Http\Request  $request
   * @param  \Closure  $next
   * @return mixed
   */
  public function handle(Request $request, Closure $next)
  {
    $database = DB::table('config_usuarios')->select('name_bd')->where("nombre_proveedor", "=", $request->proveedor)->where("estado", "=", 1)->get();

    if (count($database) > 0) {
      $nombreDB = $database[0]->name_bd;
      session(['nameBd89' => $nombreDB]);

      DB::purge('mysql');
      Config::set('database.connections.mysql.database', $nombreDB);
      DB::reconnect('mysql'); //Asigno la nueva conexión al sistema. 

      return $next($request);
    } else {

      // // return redirect()
      // // ->back()
      // // ->with('mensaje_error','ERROR, RUT NO IDENTIFICADO');
      // Session::flash('mensaje_error', 'ERROR, RUT NO IDENTIFICADO');
      // return redirect()->to('/api/identificacion?error=' . "1");
      // // return redirect('/api/identificacion');
      $nombreDB = strtoupper($request->proveedor);
      session(['nameBd89' => $nombreDB]);

      DB::purge('mysql');
      Config::set('database.connections.mysql.database', $nombreDB);
      DB::reconnect('mysql'); //Asigno la nueva conexión al sistema. 

      return $next($request);
    }
  }
}
